package com.pwt.web.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.pwt.web.mapper.PwtRobotFaultMapper;
import com.pwt.web.domain.PwtRobotFault;
import com.pwt.web.service.IPwtRobotFaultService;

/**
 * 机器人故障信息Service业务层处理
 * 
 * @author pwt
 * @date 2022-11-23
 */
@Service
public class PwtRobotFaultServiceImpl implements IPwtRobotFaultService 
{
    @Autowired
    private PwtRobotFaultMapper pwtRobotFaultMapper;

    /**
     * 查询机器人故障信息
     * 
     * @param id 机器人故障信息主键
     * @return 机器人故障信息
     */
    @Override
    public PwtRobotFault selectPwtRobotFaultById(Long id)
    {
        return pwtRobotFaultMapper.selectPwtRobotFaultById(id);
    }

    /**
     * 查询机器人故障信息列表
     * 
     * @param pwtRobotFault 机器人故障信息
     * @return 机器人故障信息
     */
    @Override
    public List<PwtRobotFault> selectPwtRobotFaultList(PwtRobotFault pwtRobotFault)
    {
        return pwtRobotFaultMapper.selectPwtRobotFaultList(pwtRobotFault);
    }

    /**
     * 新增机器人故障信息
     * 
     * @param pwtRobotFault 机器人故障信息
     * @return 结果
     */
    @Override
    public int insertPwtRobotFault(PwtRobotFault pwtRobotFault)
    {
        return pwtRobotFaultMapper.insertPwtRobotFault(pwtRobotFault);
    }

    /**
     * 修改机器人故障信息
     * 
     * @param pwtRobotFault 机器人故障信息
     * @return 结果
     */
    @Override
    public int updatePwtRobotFault(PwtRobotFault pwtRobotFault)
    {
        return pwtRobotFaultMapper.updatePwtRobotFault(pwtRobotFault);
    }

    /**
     * 批量删除机器人故障信息
     * 
     * @param ids 需要删除的机器人故障信息主键
     * @return 结果
     */
    @Override
    public int deletePwtRobotFaultByIds(Long[] ids)
    {
        return pwtRobotFaultMapper.deletePwtRobotFaultByIds(ids);
    }

    /**
     * 删除机器人故障信息信息
     * 
     * @param id 机器人故障信息主键
     * @return 结果
     */
    @Override
    public int deletePwtRobotFaultById(Long id)
    {
        return pwtRobotFaultMapper.deletePwtRobotFaultById(id);
    }

    /**
     * 查询机器人故障信息
     *
     * @param subscript 机器人故障信息下标
     * @return 机器人故障信息
     */
    @Override
    public PwtRobotFault selectRobotFaultBySubscript(int subscript)
    {
        return pwtRobotFaultMapper.selectRobotFaultBySubscript(subscript);
    }
}
